==> apache-hop-1.1.0-src.tar.gz: apache-hop-1.1.0/plugins/transforms/kafka/src/main/java/org/apache/hop/pipeline/transforms/kafka/consumer/KafkaConsumerInputData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.kafka.consumer;

import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.RowProducer;
import org.apache.hop.pipeline.SingleThreadedPipelineExecutor;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;
import org.apache.kafka.clients.consumer.Consumer;

import java.util.List;

public class KafkaConsumerInputData extends BaseTransformData implements ITransformData {
  public IRowMeta outputRowMeta;
  public Consumer consumer;
  public int batch;
  public RowProducer rowProducer;
  public SingleThreadedPipelineExecutor executor;
  public boolean isKafkaConsumerClosing;
  public List<Object[]> incomingRowsBuffer;


  /** */
  public KafkaConsumerInputData() {
    super();
  }
}

==> apache-hop-2.1.0-src.tar.gz: apache-hop-2.1.0/plugins/transforms/kafka/src/main/java/org/apache/hop/pipeline/transforms/kafka/consumer/KafkaConsumerInputData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.kafka.consumer;

import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.RowProducer;
import org.apache.hop.pipeline.SingleThreadedPipelineExecutor;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;
import org.apache.kafka.clients.consumer.Consumer;

import java.util.List;

public class KafkaConsumerInputData extends BaseTransformData implements ITransformData {
  public IRowMeta outputRowMeta;
  public Consumer<Object, Object> consumer;
  public int batchDuration;
  public int batchSize;
  public RowProducer rowProducer;
  public SingleThreadedPipelineExecutor executor;
  public boolean isKafkaConsumerClosing;
  public List<Object[]> incomingRowsBuffer;


  /** */
  public KafkaConsumerInputData() {
    super();
  }
}
